@@ -2,5 +2,5 @@ var searchData=
 [
   ['attributetype_0',['AttributeType',['../../vstsdk/structSteinberg_1_1Vst_1_1UMP_1_1IUniversalMidiPacketHandler.html#a2d5e4c58e564a3a5dcba2d56100fdb1c',1,'Steinberg::Vst::UMP::IUniversalMidiPacketHandler']]],
   ['attributevalue_1',['AttributeValue',['../../vstsdk/structSteinberg_1_1Vst_1_1UMP_1_1IUniversalMidiPacketHandler.html#ac74d8cd6bfdc888b318de9ebdffc5eb7',1,'Steinberg::Vst::UMP::IUniversalMidiPacketHandler']]],
-  ['attrid_2',['AttrID',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IAttributeList.html#afbcb28dffd98773ba0287d888f16d00a',1,'Steinberg::Vst::IAttributeList']]]
+  ['attrid_2',['AttrID',['../../vstinterfaces/group__vst3typedef.html#gafbcb28dffd98773ba0287d888f16d00a',1,'Steinberg::Vst::IAttributeList::AttrID'],['../../vstinterfaces/group__vst3typedef.html#gafbcb28dffd98773ba0287d888f16d00a',1,'Steinberg::Vst::IAttributeList::AttrID']]]
 ];
