@@ -2,6 +2,6 @@ var searchData=
 [
   ['readindex_0',['readIndex',['../classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a03027b3181599682f2c0e1d099276726',1,'Steinberg::Vst::ParameterChangeTransfer']]],
   ['right_1',['right',['../../base/structSteinberg_1_1ViewRect.html#a773c879226336b9859a3dec0a7f8e6ca',1,'Steinberg::ViewRect']]],
-  ['root_2',['root',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ChordEvent.html#a109c9addbf0865629fcb10fede22de26',1,'Steinberg::Vst::ChordEvent::root()'],['../../vstinterfaces/structSteinberg_1_1Vst_1_1ScaleEvent.html#a109c9addbf0865629fcb10fede22de26',1,'Steinberg::Vst::ScaleEvent::root()']]],
+  ['root_2',['root',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ChordEvent.html#a109c9addbf0865629fcb10fede22de26',1,'Steinberg::Vst::ChordEvent::root'],['../../vstinterfaces/structSteinberg_1_1Vst_1_1ScaleEvent.html#a109c9addbf0865629fcb10fede22de26',1,'Steinberg::Vst::ScaleEvent::root']]],
   ['rootnote_3',['rootNote',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Chord.html#a618acffbc29c4bc4ba7ffd114686c235',1,'Steinberg::Vst::Chord']]]
 ];
